@@ -1,3 +1,4 @@
-from .citeurl import Citator, Citation, Template, cite, list_cites
+from .citation import Citation
+from .citator import Citator, Template, cite, list_cites
 from .tokens import TokenType, TokenOperation, StringBuilder
 from .hyperlink import insert_links
